INSTALLED_APPS = (
    'oauth_tokens',
    'facebook_api',
    'facebook_posts',
)

OAUTH_TOKENS_FACEBOOK_CLIENT_ID = 0
OAUTH_TOKENS_FACEBOOK_CLIENT_SECRET = ''
OAUTH_TOKENS_FACEBOOK_SCOPE = ['offline_access']
OAUTH_TOKENS_FACEBOOK_USERNAME = '+919665223715'
OAUTH_TOKENS_FACEBOOK_PASSWORD = 'githubovich'